@@ -45,90 +45,94 @@ class BaseTestRMA(object):
         group = self.WIN.Get_group()
         size = group.Get_size()
         group.Free()
-        for array in arrayimpl.ArrayTypes:
-            for typecode in arrayimpl.TypeMap:
-                for count in range(self.COUNT_MIN, 10):
-                    for rank in range(size):
-                        sbuf = array([rank]*count, typecode)
-                        rbuf = array(-1, typecode, count+1)
-                        self.WIN.Fence()
-                        self.WIN.Lock(rank)
-                        r = self.WIN.Rput(sbuf.as_mpi(), rank)
-                        r.Wait()
-                        self.WIN.Flush(rank)
-                        r = self.WIN.Rget(rbuf.as_mpi_c(count), rank)
-                        r.Wait()
-                        self.WIN.Unlock(rank)
-                        for i in range(count):
-                            self.assertEqual(sbuf[i], rank)
-                            self.assertEqual(rbuf[i], rank)
-                        self.assertEqual(rbuf[-1], -1)
+        for array, typecode in arrayimpl.subTest(self):
+            if unittest.is_mpi_gpu('mvapich2', array): continue
+            for count in range(self.COUNT_MIN, 10):
+                for rank in range(size):
+                    sbuf = array([rank]*count, typecode)
+                    rbuf = array(-1, typecode, count+1)
+                    self.WIN.Fence()
+                    self.WIN.Lock(rank)
+                    r = self.WIN.Rput(sbuf.as_mpi(), rank)
+                    r.Wait()
+                    self.WIN.Flush(rank)
+                    r = self.WIN.Rget(rbuf.as_mpi_c(count), rank)
+                    r.Wait()
+                    self.WIN.Unlock(rank)
+                    for i in range(count):
+                        self.assertEqual(sbuf[i], rank)
+                        self.assertEqual(rbuf[i], rank)
+                    self.assertEqual(rbuf[-1], -1)
 
     @unittest.skipMPI('openmpi(>=1.10.0,<1.11.0)')
     def testAccumulate(self):
         group = self.WIN.Get_group()
         size = group.Get_size()
         group.Free()
-        for array in arrayimpl.ArrayTypes:
-            for typecode in arrayimpl.TypeMap:
-                for count in range(self.COUNT_MIN, 10):
-                    for rank in range(size):
-                        ones = array([1]*count, typecode)
-                        sbuf = array(range(count), typecode)
-                        rbuf = array(-1, typecode, count+1)
-                        for op in (MPI.SUM, MPI.PROD,
-                                   MPI.MAX, MPI.MIN,
-                                   MPI.REPLACE):
-                            self.WIN.Lock(rank)
-                            self.WIN.Put(ones.as_mpi(), rank)
-                            self.WIN.Flush(rank)
-                            r = self.WIN.Raccumulate(sbuf.as_mpi(),
-                                                     rank, op=op)
-                            r.Wait()
-                            self.WIN.Flush(rank)
-                            r = self.WIN.Rget(rbuf.as_mpi_c(count), rank)
-                            r.Wait()
-                            self.WIN.Unlock(rank)
-                            #
-                            for i in range(count):
-                                self.assertEqual(sbuf[i], i)
-                                self.assertEqual(rbuf[i], op(1, i))
-                            self.assertEqual(rbuf[-1], -1)
+        for array, typecode in arrayimpl.subTest(self):
+            if unittest.is_mpi_gpu('openmpi', array): continue
+            if unittest.is_mpi_gpu('mvapich2', array): continue
+            if typecode in 'FDG': continue
+            for count in range(self.COUNT_MIN, 10):
+                for rank in range(size):
+                    ones = array([1]*count, typecode)
+                    sbuf = array(range(count), typecode)
+                    rbuf = array(-1, typecode, count+1)
+                    for op in (MPI.SUM, MPI.PROD,
+                               MPI.MAX, MPI.MIN,
+                               MPI.REPLACE):
+                        self.WIN.Lock(rank)
+                        self.WIN.Put(ones.as_mpi(), rank)
+                        self.WIN.Flush(rank)
+                        r = self.WIN.Raccumulate(sbuf.as_mpi(),
+                                                 rank, op=op)
+                        r.Wait()
+                        self.WIN.Flush(rank)
+                        r = self.WIN.Rget(rbuf.as_mpi_c(count), rank)
+                        r.Wait()
+                        self.WIN.Unlock(rank)
+                        #
+                        for i in range(count):
+                            self.assertEqual(sbuf[i], i)
+                            self.assertEqual(rbuf[i], op(1, i))
+                        self.assertEqual(rbuf[-1], -1)
 
     @unittest.skipMPI('openmpi(>=1.10,<1.11)')
     def testGetAccumulate(self):
         group = self.WIN.Get_group()
         size = group.Get_size()
         group.Free()
-        for array in arrayimpl.ArrayTypes:
-            for typecode in arrayimpl.TypeMap:
-                for count in range(self.COUNT_MIN, 10):
-                    for rank in range(size):
-                        ones = array([1]*count, typecode)
-                        sbuf = array(range(count), typecode)
-                        rbuf = array(-1, typecode, count+1)
-                        gbuf = array(-1, typecode, count+1)
-                        for op in (MPI.SUM, MPI.PROD,
-                                   MPI.MAX, MPI.MIN,
-                                   MPI.REPLACE, MPI.NO_OP):
-                            self.WIN.Lock(rank)
-                            self.WIN.Put(ones.as_mpi(), rank)
-                            self.WIN.Flush(rank)
-                            r = self.WIN.Rget_accumulate(sbuf.as_mpi(),
-                                                         rbuf.as_mpi_c(count),
-                                                         rank, op=op)
-                            r.Wait()
-                            self.WIN.Flush(rank)
-                            r = self.WIN.Rget(gbuf.as_mpi_c(count), rank)
-                            r.Wait()
-                            self.WIN.Unlock(rank)
-                            #
-                            for i in range(count):
-                                self.assertEqual(sbuf[i], i)
-                                self.assertEqual(rbuf[i], 1)
-                                self.assertEqual(gbuf[i], op(1, i))
-                            self.assertEqual(rbuf[-1], -1)
-                            self.assertEqual(gbuf[-1], -1)
+        for array, typecode in arrayimpl.subTest(self):
+            if unittest.is_mpi_gpu('openmpi', array): continue
+            if unittest.is_mpi_gpu('mvapich2', array): continue
+            if typecode in 'FDG': continue
+            for count in range(self.COUNT_MIN, 10):
+                for rank in range(size):
+                    ones = array([1]*count, typecode)
+                    sbuf = array(range(count), typecode)
+                    rbuf = array(-1, typecode, count+1)
+                    gbuf = array(-1, typecode, count+1)
+                    for op in (MPI.SUM, MPI.PROD,
+                               MPI.MAX, MPI.MIN,
+                               MPI.REPLACE, MPI.NO_OP):
+                        self.WIN.Lock(rank)
+                        self.WIN.Put(ones.as_mpi(), rank)
+                        self.WIN.Flush(rank)
+                        r = self.WIN.Rget_accumulate(sbuf.as_mpi(),
+                                                     rbuf.as_mpi_c(count),
+                                                     rank, op=op)
+                        r.Wait()
+                        self.WIN.Flush(rank)
+                        r = self.WIN.Rget(gbuf.as_mpi_c(count), rank)
+                        r.Wait()
+                        self.WIN.Unlock(rank)
+                        #
+                        for i in range(count):
+                            self.assertEqual(sbuf[i], i)
+                            self.assertEqual(rbuf[i], 1)
+                            self.assertEqual(gbuf[i], op(1, i))
+                        self.assertEqual(rbuf[-1], -1)
+                        self.assertEqual(gbuf[-1], -1)
 
     def testPutProcNull(self):
         rank = self.COMM.Get_rank()
